@@ -9,7 +9,7 @@ use Module::Runtime;
 use Params::Util 0.14 ();
 use Try::Tiny;
 
-our $VERSION = '0.002';
+our $VERSION = '0.003';
 
 has driver => (
     is      => 'ro',
@@ -120,7 +120,7 @@ Parcel::Track - Driver-based API for tracking parcel
 
 =head1 VERSION
 
-version 0.002
+version 0.003
 
 =head1 SYNOPSIS
 
@@ -168,8 +168,8 @@ You can access attributes and methods of specific driver.
         _username => 'keedi',
         _password => 'keedi',
     );
-    $tracker->driver->_username;
-    $tracker->driver->_password;
+    $tracker->driver->username; # NOT _username BUT username
+    $tracker->driver->password; # NOT _password BUT password
     $tracker->driver->foo( $dummy1 );
     $tracker->driver->bar( $dummy2, $dummy3 );
 
@@ -204,7 +204,14 @@ standardised features within the L<Parcel::Track> API itself. At this
 time, there are no usable public options.
 
 Params B<with> a leading underscore are "private" driver-specific options
-and will be passed through to the driver unchanged.
+and will be passed through to the driver B<without> the underscore.
+
+    $tracker = Parcel::Track->new( 'MyDriver', '123-456-789-012',
+        _username => 'keedi',
+        _password => 'keedi',
+    );
+    $tracker->driver->username; # NOT _username BUT username
+    $tracker->driver->password; # NOT _password BUT password
 
 Returns a new L<Parcel::Track> object, or dies on error.
 
